extensions FEATURE YANG extension plugins support with NACM as proof-of-concept
diff --git a/src/tree_schema.c b/src/tree_schema.c
index d828c67..ad8e695 100644
--- a/src/tree_schema.c
+++ b/src/tree_schema.c
@@ -751,8 +751,9 @@
 #endif
 
     if (!mod->implemented) {
         /* pre-compile features of the module */
         LY_CHECK_GOTO(lys_feature_precompile(NULL, ctx, mod, mod->parsed->features, &mod->off_features), error);
+        LY_CHECK_GOTO(lys_extension_precompile(NULL, ctx, mod, mod->parsed->extensions, &mod->off_extensions), error);
     }
 
     /* decide the latest revision */
@@ -797,8 +798,9 @@
             goto error_ctx;
         }
         if (!mod->implemented) {
             /* pre-compile features of the module */
             LY_CHECK_GOTO(lys_feature_precompile(NULL, ctx, mod, inc->submodule->features, &mod->off_features), error);
+            LY_CHECK_GOTO(lys_extension_precompile(NULL, ctx, mod, mod->parsed->extensions, &mod->off_extensions), error);
         }
     }
     mod->parsed->parsing = 0;
@@ -751,8 +751,9 @@
 
     if (!mod->implemented) {
-        /* pre-compile features of the module */
+        /* pre-compile features and extension definitions of the module */
         LY_CHECK_GOTO(lys_feature_precompile(NULL, ctx, mod, mod->parsed->features, &mod->off_features), error);
@@ -797,8 +798,9 @@
         }
         if (!mod->implemented) {
-            /* pre-compile features of the module */
+            /* pre-compile features and extension definitions of the module */
             LY_CHECK_GOTO(lys_feature_precompile(NULL, ctx, mod, inc->submodule->features, &mod->off_features), error);